@@ -11,7 +11,7 @@ use base qw( Tickit IO::Async::Notifier );
 Tickit->VERSION( '0.17' );
 IO::Async::Notifier->VERSION( '0.43' ); # Need support for being a nonprinciple mixin
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 use IO::Async::Loop 0.47; # ->run and ->stop methods
 use IO::Async::Signal;
@@ -162,17 +162,20 @@ sub run
 
    $self->setup_term;
 
+   my $running = 1;
+
    $loop->add( my $sigint_notifier = IO::Async::Signal->new(
       name => "INT",
-      on_receipt => $self->_capture_weakself( sub {
-            my $self = shift;
-            if( my $loop = $self->get_loop ) {
-               $loop->stop
-            }
-         }),
+      on_receipt => $self->_capture_weakself( sub { undef $running }),
    ) );
 
-   my $ret = eval { $loop->run };
+   my $ret = eval {
+      $self->_flush;
+      while($running) {
+         $loop->loop_once;
+         $self->_flush;
+      }
+   };
    my $e = $@;
 
    {
